@@ -66,7 +66,7 @@ def sync_customers():
 
 
 @cmd.command()
-def fup_or_defup():
+def update_history():
     """Udpate all customers total comsumption"""
     limits = {
         'business_access': {'limit': 50, 'policy': 'business_access_1'},
@@ -94,11 +94,6 @@ def fup_or_defup():
             )
         )
         core.update_consommation(product, policy, customer_name, fup_status, consumption)
-
-        # if fup_status:
-        #     core.fup_customer(customer_name)
-        # else:
-        #     core.defup_customer(customer_name)
     LOGS.logger.info("Sync customers from CRM -- END")
 
 
@@ -139,6 +134,32 @@ def sync(last_date, product_ese):
     )
 
 
+@cmd.command()
+def fup_or_defup():
+    """FUP customers in over-quota and DEFUP under quota"""
+    LOGS.logger.info("Fup or defup customers -- START")
+    yesterday = (dt.today() - timedelta(days=1)).strftime("%Y-%m-%d")
+
+    customers_si = core.get_customers_si()
+    for customer in customers_si:
+        customer_name = customer['name']
+        history = core.get_history(customer_name, yesterday)
+
+        if history:
+            if history['status']:
+                core.fup_customer(customer_name)
+            else:
+                core.defup_customer(customer_name)
+        else:
+            operation = "get customer {} total consumption for {}".format(customer_name, yesterday)
+            LOGS.logger.error("Unable to {}. No history found.".format(operation))
+            core.send_error_report(
+                operation=operation,
+                error="No history found for that date"
+            )
+    LOGS.logger.info("Fup or defup customers -- END")
+
+
 @cmd.command()
 @click.option('--start-date', default=False)
 @click.option('--stop-date', default=False)
@@ -149,15 +170,22 @@ def notify(start_date, stop_date):
     msg_client = ' '
     product_types = CONFIG['PRODUCT']['product_type'].split(',')
     for product_type in product_types:
+
+        # GP customer list from CRM
         customers = Product_GP.all(product_type)
+
         for customer in customers:
             click.echo('Notification du client {}'.format(customer.ident))
             url = core.database_url(**FUPDB_CREDENTIALS)
+
+            # get customer information in database
             with records.Database(url) as db:
                 sql = "SELECT refnum, product FROM customer WHERE name=:name"
                 rows = db.query(sql, name=customer.ident.lower())
                 row = rows.first()
-                if not row and customer.type_ident.lower() == 'ident':
+
+
+                if not row and customer.type_ident.lower() == 'ident':  # msisdn, mac, ident
                     msg_client += "Le client {name} n'existe pas.\n".format(
                         name=customer.ident.lower()
                         )
@@ -165,6 +193,7 @@ def notify(start_date, stop_date):
                         customer.ident.lower()
                         ))
                 else:
+
                     response = customer.notify(start_date, stop_date)
                     if not response:
                         click.echo("Pas de notification à envoyer")
@@ -174,6 +203,7 @@ def notify(start_date, stop_date):
                         if status:
                             msg = '{} ({})'.format(msg, 'Notification envoyée')
                         click.echo(msg)
+
         if msg_client.strip() != '':
             dest = CONFIG['ALERT']['to_1']
             content = MIMEText(msg_client, 'plain', 'utf-8')
