@@ -190,25 +190,25 @@ def get_customers_crm(product_name):
         )
 
 
-def get_last_history(customer_name):
+def get_history(customer_name, date):
     """
-    Get a given customer's last fup history in fup-services database.
+    Get a given customer's fup history in fup-services database.
     :param customer_name: name of the customer, already lowered
+    :param date: YYYY-mm-dd
     """
     try:
         with records.Database(si_database_url()) as db:
             sql = (
                 "SELECT * FROM fup "
-                "WHERE datetime = "
-                "(SELECT MAX(datetime) FROM fup "
-                "WHERE customer='{name}') "
-            ).format(name=customer_name)
+                "WHERE datetime={date}::date "
+                "AND customer='{name}') "
+            ).format(name=customer_name, date=date)
             rows = db.query(sql)
             fup_history = rows.as_dict()
         return fup_history[0]
     except Exception as e:
         operation = (
-            "get customer {}'s last fup history in SI database"
+            "get customer {}'s fup history in SI database"
             .format(customer_name)
         )
         LOGS.logger.error("Unable to {}".format(operation))
